@@ -933,7 +933,7 @@ def write_log_html(shells, ready_shells, args, versions_dict, flag_sets,
             page += '\t\t</div>\n'
     page += """
 \t<h2>References</h2>
-\t\tPlease reference the used software:
+\t\tPlease cite the used software:
 \t\t<ul>
 \t\t<li>Paired refinement under the control of <i>PAIREF</i>. M. Maly, K. Diederichs, J. Dohnalek, P. Kolenko (2020) <i>IUCrJ</i> <b>7</b></li>
 """
